@@ -49,15 +49,13 @@ static const int DEFAULT_POPUP_TYPE = KPassivePopup::Boxed;
 static const int DEFAULT_POPUP_TIME = 6 * 1000;
 static const Qt::WindowFlags POPUP_FLAGS = Qt::Tool | Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint;
 
-class KPassivePopup::Private
+class Q_DECL_HIDDEN KPassivePopup::Private
 {
 public:
     Private(KPassivePopup *q, WId winId)
         : q(q),
           popupStyle(DEFAULT_POPUP_TYPE),
           window(winId),
-          msgView(nullptr),
-          topLayout(nullptr),
           hideDelay(DEFAULT_POPUP_TIME),
           hideTimer(new QTimer(q)),
           autoDelete(false)
@@ -78,8 +76,8 @@ public:
         } else if (popupStyle == Balloon) {
             q->setPalette(QToolTip::palette());
         }
-        connect(hideTimer, SIGNAL(timeout()), q, SLOT(hide()));
-        connect(q, SIGNAL(clicked()), q, SLOT(hide()));
+        connect(hideTimer, &QTimer::timeout, q, &QWidget::hide);
+        connect(q, QOverload<>::of(&KPassivePopup::clicked), q, &QWidget::hide);
     }
 
     KPassivePopup *q;
@@ -90,14 +88,14 @@ public:
     QPoint fixedPosition;
 
     WId window;
-    QWidget *msgView;
-    QBoxLayout *topLayout;
+    QWidget *msgView = nullptr;
+    QBoxLayout *topLayout = nullptr;
     int hideDelay;
-    QTimer *hideTimer;
+    QTimer *hideTimer = nullptr;
 
-    QLabel *ttlIcon;
-    QLabel *ttl;
-    QLabel *msg;
+    QLabel *ttlIcon = nullptr;
+    QLabel *ttl = nullptr;
+    QLabel *msg = nullptr;
 
     bool autoDelete;
 
@@ -144,7 +142,7 @@ public:
             QPolygon corner = path.toFillPolygon().toPolygon();
 
             surround.resize(z + corner.count() - 1);
-            for (int s = 1; s < corner.count() - 1; s++, z++) {
+            for (int s = 1; s < corner.count() - 1; ++s, ++z) {
                 surround.setPoint(z, corner[s]);
             }
 
@@ -457,7 +455,7 @@ void KPassivePopup::positionSelf()
 #if HAVE_X11
         if (QX11Info::isPlatformX11()) {
             NETWinInfo ni(QX11Info::connection(), d->window, QX11Info::appRootWindow(),
-                          NET::WMIconGeometry | NET::WMState, 0);
+                          NET::WMIconGeometry | NET::WMState, NET::Properties2());
 
             // Try to put the popup by the taskbar entry
             if (!(ni.state() & NET::SkipTaskbar)) {
