@@ -38,20 +38,20 @@ class NotifyByPopup : public KNotificationPlugin
     Q_OBJECT
 public:
     explicit NotifyByPopup(QObject *parent = nullptr);
-    virtual ~NotifyByPopup();
+    ~NotifyByPopup() override;
 
-    QString optionName() Q_DECL_OVERRIDE { return QStringLiteral("Popup"); }
-    void notify(KNotification *notification, KNotifyConfig *notifyConfig) Q_DECL_OVERRIDE;
-    void close(KNotification *notification) Q_DECL_OVERRIDE;
-    void update(KNotification *notification, KNotifyConfig *config) Q_DECL_OVERRIDE;
+    QString optionName() override { return QStringLiteral("Popup"); }
+    void notify(KNotification *notification, KNotifyConfig *notifyConfig) override;
+    void close(KNotification *notification) override;
+    void update(KNotification *notification, KNotifyConfig *config) override;
 
 protected:
-    void timerEvent(QTimerEvent *event) Q_DECL_OVERRIDE;
+    void timerEvent(QTimerEvent *event) override;
 
 private Q_SLOTS:
     void onPassivePopupDestroyed();
     void onPassivePopupLinkClicked(const QString &link);
-    // slot to catch appearance or dissapearance of Notifications DBus service
+    // slot to catch appearance or disappearance of Notifications DBus service
     void onServiceOwnerChanged(const QString &, const QString &, const QString &);
     // slot which gets called when DBus signals that some notification action was invoked
     void onGalagoNotificationActionInvoked(uint notificationId, const QString &actionKey);
@@ -68,6 +68,7 @@ private:
     void update(KNotification *notification, const KNotifyConfig &notifyConfig);
 
     NotifyByPopupPrivate * const d;
+    friend class NotifyByPopupPrivate;
 };
 
 #endif
